from os import listdir
from OTils.size_utils import parse_size, file_size

def get_list_of_files_of_approximate_size(list_of_files, total_size):
    size_in_bytes = parse_size(total_size)
    accumulated_size = 0
    error = abs(size_in_bytes-accumulated_size)
    length = 0

    for file_path in  list_of_files:
        fsize = file_size(file_path)
        temporary_accumulated_size = accumulated_size+fsize
        temporary_error = abs(size_in_bytes-(temporary_accumulated_size))
        if temporary_error < error:
            accumulated_size = temporary_accumulated_size
            error = temporary_error
            length += 1
        else:
            break
    
    selected_files = list_of_files[:length]
    return selected_files
    


def file_dealer(number_of_files=None, total_size=None):
    """
    Small function to get some input filenames fast.

    We can get a list of a certain length using the argument number_of_files or files that add up to a certain size (in GB).
    """

    # Some files from Tobias Selz
    files_folder = '/project/meteo-scratch/Tobias.Selz/stspectra/10asim/icon_out/'

    file_names = listdir(files_folder)

    # ML files are about 280MB and PL files are about 950MB
    # We wll use ML files for now
    ML_file_names = [f for f in file_names if f.count("NWP_lonlat_ML")]
    PL_file_names = [f for f in file_names if f.count("NWP_lonlat_PL")]

    file_names = ML_file_names
    file_paths = [f"{files_folder}/{fn}" for fn in file_names]


    if number_of_files is not None:
        if number_of_files > len(file_paths):
            print(f"You requested {number_of_files} files which is more than the number of files available: {len(file_paths)}")
            exit(1)
        return file_paths[:number_of_files]
    elif total_size is not None:
        return get_list_of_files_of_approximate_size(file_paths, total_size)

    else:
        raise AssertionError("At least one argument is required:\n number_of_files or total_size")
        

if __name__ == "__main__":
    files = file_dealer(total_size="5GB")
    print(files)
